==> esp32c3-0.2.0.crate: esp32c3-0.2.0/src/gpio/enable_w1ts.rs <==
#[doc = "Register `ENABLE_W1TS` writer"]
pub struct W(crate::W<ENABLE_W1TS_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<ENABLE_W1TS_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<ENABLE_W1TS_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<ENABLE_W1TS_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `ENABLE_W1TS` writer - GPIO output enable set register for GPIO0-25"]
pub struct ENABLE_W1TS_W<'a> {
    w: &'a mut W,
}
impl<'a> ENABLE_W1TS_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x03ff_ffff) | (value as u32 & 0x03ff_ffff);
        self.w
    }
}
impl W {
    #[doc = "Bits 0:25 - GPIO output enable set register for GPIO0-25"]
    #[inline(always)]
    pub fn enable_w1ts(&mut self) -> ENABLE_W1TS_W {
        ENABLE_W1TS_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "GPIO output enable set register\n\nThis register you can [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [enable_w1ts](index.html) module"]
pub struct ENABLE_W1TS_SPEC;
impl crate::RegisterSpec for ENABLE_W1TS_SPEC {
    type Ux = u32;
}
#[doc = "`write(|w| ..)` method takes [enable_w1ts::W](W) writer structure"]
impl crate::Writable for ENABLE_W1TS_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets ENABLE_W1TS to value 0"]
impl crate::Resettable for ENABLE_W1TS_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp32c3-0.4.0.crate: esp32c3-0.4.0/src/gpio/enable_w1ts.rs <==
#[doc = "Register `ENABLE_W1TS` writer"]
pub struct W(crate::W<ENABLE_W1TS_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<ENABLE_W1TS_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<ENABLE_W1TS_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<ENABLE_W1TS_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `ENABLE_W1TS` writer - GPIO output enable set register for GPIO0-25"]
pub struct ENABLE_W1TS_W<'a> {
    w: &'a mut W,
}
impl<'a> ENABLE_W1TS_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x03ff_ffff) | (value as u32 & 0x03ff_ffff);
        self.w
    }
}
impl W {
    #[doc = "Bits 0:25 - GPIO output enable set register for GPIO0-25"]
    #[inline(always)]
    pub fn enable_w1ts(&mut self) -> ENABLE_W1TS_W {
        ENABLE_W1TS_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "GPIO output enable set register\n\nThis register you can [`write_with_zero`]
(crate::generic::Reg::write_with_zero), [`reset`]
(crate::generic::Reg::reset), [`write`]
(crate::generic::Reg::write). See [API]
(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [enable_w1ts]
(index.html) module"]
pub struct ENABLE_W1TS_SPEC;
impl crate::RegisterSpec for ENABLE_W1TS_SPEC {
    type Ux = u32;
}
#[doc = "`write(|w| ..)` method takes [enable_w1ts::W]
(W) writer structure"]
impl crate::Writable for ENABLE_W1TS_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets ENABLE_W1TS to value 0"]
impl crate::Resettable for ENABLE_W1TS_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
